==> flink-1.14.2-src.tgz: flink-1.14.2/flink-runtime-web/web-dashboard/src/app/interfaces/job-exception.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export interface JobExceptionInterface {
  'root-exception': string;
  timestamp: number;
  truncated: boolean;
  'all-exceptions': JobExceptionItemInterface[];
  'exceptionHistory': JobExceptionHistoryInterface;
}

export interface JobExceptionItemInterface {
  'attempt-num': number;
  exception: string;
  location: string;
  'subtask-index': number;
  task: string;
  timestamp: number;
  'vertex-id': string;
}

export interface JobExceptionHistoryInterface {
  entries: RootExceptionInfoInterface[];
  truncated: boolean;
}

export interface ExceptionInfoInterface {
  exceptionName: string;
  stacktrace: string;
  timestamp: number;
  taskName: string;
  location: string;
}

export interface RootExceptionInfoInterface extends ExceptionInfoInterface {
  concurrentExceptions: ExceptionInfoInterface[];
}

==> flink-1.18.1-src.tgz: flink-1.18.1/flink-runtime-web/web-dashboard/src/app/interfaces/job-exception.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export interface JobException {
  'root-exception': string;
  timestamp: number;
  truncated: boolean;
  'all-exceptions': JobExceptionItem[];
  exceptionHistory: JobExceptionHistory;
}

export interface JobExceptionItem {
  'attempt-num': number;
  exception: string;
  location: string;
  'subtask-index': number;
  task: string;
  timestamp: number;
  'vertex-id': string;
}

export interface JobExceptionHistory {
  entries: RootExceptionInfo[];
  truncated: boolean;
}

export interface ExceptionInfo {
  exceptionName: string;
  stacktrace: string;
  timestamp: number;
  taskName: string;
  location: string;
}

export interface RootExceptionInfo extends ExceptionInfo {
  concurrentExceptions: ExceptionInfo[];
}
